Who Is Using It?
================

These are some projects using this extension
that you can take a look at to understand how they are configured and what's the behavior.


Read the Docs
-------------

* https://github.com/readthedocs/readthedocs.org
* `Example URL <https://docs.readthedocs.io/en/stable/not/found.html>`__
* `Configuration file <https://github.com/readthedocs/readthedocs.org/blob/master/docs/conf.py>`__


PyVista
-------

* https://github.com/pyvista/pyvista
* `Example URL <https://docs.pyvista.org/not/found/page.html>`__
* `Configuration file <https://github.com/pyvista/pyvista/blob/master/docs/conf.py>`__


Write the Docs
--------------

* https://github.com/writethedocs/www
* `Example URL <https://www.writethedocs.org/404/>`__
* `Configuration file <https://github.com/writethedocs/www/blob/master/docs/conf.py>`__


The Carpentries
---------------

* https://github.com/carpentries/handbook
* `Example URL <https://docs.carpentries.org/404/>`__
* `Configuration file <https://github.com/carpentries/handbook/blob/master/conf.py>`__


attrs
-----

* https://www.attrs.org/
* `Example URL <https://www.attrs.org/en/latest/404>`__
* `Configuration file <https://github.com/python-attrs/attrs/blob/main/docs/conf.py>`__
